@@ -23,6 +23,7 @@ from tencentcloud.es.v20180416 import models
 class EsClient(AbstractClient):
     _apiVersion = '2018-04-16'
     _endpoint = 'es.tencentcloudapi.com'
+    _service = 'es'
 
 
     def CreateInstance(self, request):
@@ -165,6 +166,62 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DiagnoseInstance(self, request):
+        """智能运维诊断集群
+
+        :param request: Request instance for DiagnoseInstance.
+        :type request: :class:`tencentcloud.es.v20180416.models.DiagnoseInstanceRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DiagnoseInstanceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DiagnoseInstance", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DiagnoseInstanceResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def GetRequestTargetNodeTypes(self, request):
+        """获取接收客户端请求的节点类型
+
+        :param request: Request instance for GetRequestTargetNodeTypes.
+        :type request: :class:`tencentcloud.es.v20180416.models.GetRequestTargetNodeTypesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.GetRequestTargetNodeTypesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("GetRequestTargetNodeTypes", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.GetRequestTargetNodeTypesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RestartInstance(self, request):
         """重启ES集群实例(用于系统版本更新等操作)
 
@@ -249,6 +306,34 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateDiagnoseSettings(self, request):
+        """更新智能运维配置
+
+        :param request: Request instance for UpdateDiagnoseSettings.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateDiagnoseSettingsRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateDiagnoseSettingsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateDiagnoseSettings", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateDiagnoseSettingsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateInstance(self, request):
         """对集群进行节点规格变更，修改实例名称，修改配置，重置密码， 添加Kibana黑白名单等操作。参数中InstanceId为必传参数，ForceRestart为选填参数，剩余参数传递组合及含义如下：
         - InstanceName：修改实例名称(仅用于标识实例)
@@ -312,6 +397,34 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateRequestTargetNodeTypes(self, request):
+        """更新接收客户端请求的节点类型
+
+        :param request: Request instance for UpdateRequestTargetNodeTypes.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateRequestTargetNodeTypesRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateRequestTargetNodeTypesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UpdateRequestTargetNodeTypes", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateRequestTargetNodeTypesResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpgradeInstance(self, request):
         """升级ES集群版本
 
